==> cobs-0.8.tgz: cobs-0.8/gb/code.php <==
<?php
/*****<! !>  Cross Walkϣҳ ******/
function grkpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 $ns=chr(34);
 while (!(($pt=strpos($tmp,"<!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!>");
        if ($pt1==0)
        {
           echo "error in WEB Greek parsing $tmp lost !&gt;<br>";
           return;
        }
        $grk=substr($tmp,$pt+2,$pt1-$pt-2);
          /***** Process line end 's' of Greek *****/
    	$grk=ereg_replace("s([\r\n ])","{$ns}\\1",$grk);
        $grk=ereg_replace("s$",$ns,$grk);

        if ($graph)
        {
          $grk=gfont($grk);
          $newtxt=$newtxt.$grk;
        }
        else
        {
          $grk=htmlspecialchars($grk);
          $newtxt=$newtxt."<!".$grk."!>";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("<!","<font face=\"BSTGreek\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!>","</nobr></font>",$txt);
  }
  return($txt);
}
/*****12 21  COBSҳ ******/
function hebpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"12"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
	$oldtmp=$tmp;
        $tmp=substr($tmp,$pt+2); //ȷ 12 һ 21ǰ
        $pt1=strpos($tmp,"21");
        if ($pt1==0)
        {
           //echo "error in WEBhebpar $tmp <br>";
           //return;
	   $tmp=$oldtmp;
	   break;
        }
        $heb=substr($tmp,0,$pt1);
        if ($graph)
        {
          $heb=pfont(mscode($heb));
          $newtxt=$newtxt.$heb;
        }
        else
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{#".$heb."#}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{#","<font face=\"COBSHebrew\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("#}","</nobr></font>",$txt);
  }
  return($txt);
}

/*****{!  !}  Hebrew Translate ҳ ******/
function hebtranpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"{!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!}");
        if ($pt1==0)
        {
           echo "error in hebtranpar $tmp need !} <br>";
           return;
        }
        $heb=substr($tmp,$pt+2,$pt1-$pt-2);
	/*********
        if ($graph)
        {
          $heb=htfont($heb);
          $newtxt=$newtxt.$heb;
        }
        else
        *********/
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{!".$heb."!}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{!","<font face=\"Hebrew Transliterate\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!}","</nobr></font>",$txt);
  }
  return($txt);
}

/***********ĸ֮ *************************/
function mscode($txt)
{
$A=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125);//ĸ
$B=array(39, 44, 46, 47, 59, 101,105,111,117,124, 93);//ĸ
$C=array(161,162,163,164,165,166,167,111,168,169,170);//ĸ
	//70,76,102,108ר 12379111 
$M=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125,
	 39, 44, 46, 47, 59, 101,105,111,117,124, 93,
	 161,162,163,164,165,166,167,123,168,169,170); //ĸȫ
$TS=array(71,78,87,89,90,103,110,119,121,122);//  $A
$SS=array(68,82,100,114);//ӦҪ䡸ĸ $C
$FS=array(35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
	  88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126); // $B
$S=array(71,78,87,89,90,103,110,119,121,122,
	 68,82,100,114,
	 35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
          88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126);//ȫ
   $len=strlen($txt);
    if ($len==0) return($txt);
    $ntxt="";
    for ($pt=0;$pt<$len;$pt=$pt+1)
    {
        $now=substr($txt,$pt,1);
	$cn=ord($now);
        if ($pt<($len-1)) //look aheadϵͳִ
	{
                $next=substr($txt,$pt+1,1);
		$cx=ord($next);
	}
        else
	{
                $next=""; //ִ
		$cx=0;
	}
	
        if (in_array($cn,$M)&&in_array($cx,$S)) //ĸҪ
        {
		$aid=array_search($cn,$M);
		$aid=$aid%11;//ʮһеĵڼ
		//ʲô
		if (in_array($cx,$FS)) //
		{
			//70,76,102,108ר 12379111 
			//70,76,102,108 
			if ((($cx==70)||($cx==76)||($cx==102)||($cx==108))
			   && (($cn==123)||($cn==79)||($cn==111)))
			   {
				$ntxt=$ntxt.chr(123).$next;
			   }
			else
                	   $ntxt=$ntxt.chr($B[$aid]).$next;
		}
		elseif (in_array($cx,$TS)) //
		{
                	$ntxt=$ntxt.chr($A[$aid]).$next;
		}
		elseif (in_array($cx,$SS)) //
		{
                	$ntxt=$ntxt.chr($C[$aid]).$next;
		}
		else die("û $next ");
                $pt=$pt+1;
	 }
        else //ش
        {
                $ntxt=$ntxt.$now;
        }
    }
    /****Ү· ******************************/
    $nyes=chr(167)."~;l'vWr>y";
    $ntxt=str_replace("i~;l'vWr>y",$nyes,$ntxt);
    $nyes=chr(167)."~'l'vWryIw";
    $ntxt=str_replace("i~'l'vWryIw",$nyes,$ntxt);
    $nyes=chr(167)."~;l'vWryIw";
    $ntxt=str_replace("i~;l'vWryIw",$nyes,$ntxt);
    $yes="^;\[";
    $nyes=chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes=" ;\[";
    $nyes=" ".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;x)";
    $nyes=chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;x)";
    $nyes=" ".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    return($ntxt);
}


?>

==> cobs-0.9.tgz: cobs-0.9/gb/code.php <==
<?php
/*****<! !>  Cross Walkϣҳ ******/
function grkpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 $ns=chr(34);
 while (!(($pt=strpos($tmp,"<!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!>");
        if ($pt1==0)
        {
           echo "error in WEB Greek parsing $tmp lost !&gt;<br>";
           return;
        }
        $grk=substr($tmp,$pt+2,$pt1-$pt-2);
          /***** Process line end 's' of Greek *****/
    	$grk=ereg_replace("s([\r\n ])","{$ns}\\1",$grk);
        $grk=ereg_replace("s$",$ns,$grk);

        if ($graph)
        {
          $grk=gfont($grk);
          $newtxt=$newtxt.$grk;
        }
        else
        {
          $grk=htmlspecialchars($grk);
          $newtxt=$newtxt."<!".$grk."!>";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("<!","<font face=\"BSTGreek\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!>","</nobr></font>",$txt);
  }
  return($txt);
}
/*****12 21  COBSҳ ******/
function hebpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"12"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
	$oldtmp=$tmp;
        $tmp=substr($tmp,$pt+2); //ȷ 12 һ 21ǰ
        $pt1=strpos($tmp,"21");
        if ($pt1==0)
        {
           //echo "error in WEBhebpar $tmp <br>";
           //return;
	   $tmp=$oldtmp;
	   break;
        }
        $heb=substr($tmp,0,$pt1);
        if ($graph)
        {
          $heb=pfont(mscode($heb));
          $newtxt=$newtxt.$heb;
        }
        else
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{#".$heb."#}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{#","<font face=\"COBSHebrew\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("#}","</nobr></font>",$txt);
  }
  return($txt);
}

/*****{!  !}  Hebrew Translate ҳ ******/
function hebtranpar($txt,$graph)
{
  $tmp=$txt;
 $newtxt="";
 while (!(($pt=strpos($tmp,"{!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
        $newtxt=$newtxt.$ok1;
        $pt1=strpos($tmp,"!}");
        if ($pt1==0)
        {
           echo "error in hebtranpar $tmp need !} <br>";
           return;
        }
        $heb=substr($tmp,$pt+2,$pt1-$pt-2);
	/*********
        if ($graph)
        {
          $heb=htfont($heb);
          $newtxt=$newtxt.$heb;
        }
        else
        *********/
        {
          $heb=htmlspecialchars($heb);
          $newtxt=$newtxt."{!".$heb."!}";
        }
        $tmp=substr($tmp,$pt1+2);
    }
    $newtxt=$newtxt.$tmp;
    $txt=$newtxt;
  if ($graph==0)
  {
    $txt=ereg_replace("{!","<font face=\"Hebrew Transliterate\" size=\"5\"><nobr>",$txt);
    $txt=ereg_replace("!}","</nobr></font>",$txt);
  }
  return($txt);
}

/***********ĸ֮ *************************/
function mscode($txt)
{
$A=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125);//ĸ
$B=array(39, 44, 46, 47, 59, 101,105,111,117,124, 93);//ĸ
$C=array(161,162,163,164,165,166,167,111,168,169,170);//ĸ
	//70,76,102,108ר 12379111 
$M=array(34, 60, 62, 63, 58,  69, 73, 79, 85, 92,125,
	 39, 44, 46, 47, 59, 101,105,111,117,124, 93,
	 161,162,163,164,165,166,167,123,168,169,170); //ĸȫ
$TS=array(33,71,78,87,89,90,103,110,119,121,122);//  $A
$SS=array(68,82,100,114);//ӦҪ䡸ĸ $C
$FS=array(35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
	  88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126); // $B
$S=array(33,71,78,87,89,90,103,110,119,121,122,
	 68,82,100,114,
	 35,36,37,38,64,66,67,70,72,74,75,76,77,80,81,83,84,86,
          88,91,97,98,99,102,104,106,107,108,109,112,113,115,116,117,
          118,120,126);//ȫ
   $len=strlen($txt);
    if ($len==0) return($txt);
    $ntxt="";
    for ($pt=0;$pt<$len;$pt=$pt+1)
    {
        $now=substr($txt,$pt,1);
	$cn=ord($now);
        if ($pt<($len-1)) //look aheadϵͳִ
	{
                $next=substr($txt,$pt+1,1);
		$cx=ord($next);
	}
        else
	{
                $next=""; //ִ
		$cx=0;
	}
	
        if (in_array($cn,$M)&&in_array($cx,$S)) //ĸҪ
        {
		$aid=array_search($cn,$M);
		$aid=$aid%11;//ʮһеĵڼ
		//ʲô
		if (in_array($cx,$FS)) //
		{
			//70,76,102,108ר 12379111 
			//70,76,102,108 
			if ((($cx==70)||($cx==76)||($cx==102)||($cx==108))
			   && (($cn==123)||($cn==79)||($cn==111)))
			   {
				$ntxt=$ntxt.chr(123).$next;
			   }
			else
                	   $ntxt=$ntxt.chr($B[$aid]).$next;
		}
		elseif (in_array($cx,$TS)) //
		{
                	$ntxt=$ntxt.chr($A[$aid]).$next;
		}
		elseif (in_array($cx,$SS)) //
		{
                	$ntxt=$ntxt.chr($C[$aid]).$next;
		}
		else die("û $next ");
                $pt=$pt+1;
	 }
        else //ش
        {
                $ntxt=$ntxt.$now;
        }
    }
    /****Ү· ******************************/
    $nyes=chr(167)."~;l'vWr>y";
    $ntxt=str_replace("i~;l'vWr>y",$nyes,$ntxt);
    $nyes=chr(167)."~'l'vWryIw";
    $ntxt=str_replace("i~'l'vWryIw",$nyes,$ntxt);
    $nyes=chr(167)."~;l'vWryIw";
    $ntxt=str_replace("i~;l'vWryIw",$nyes,$ntxt);
    $yes="(^;H)";
    $nyes=chr(165).chr(72);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;H)";
    $nyes=" ".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;H)";
    $nyes="\n".chr(165)."H";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="^;\[";
    $nyes=chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes=" ;\[";
    $nyes=" ".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="\n;\[";
    $nyes="\n".chr(165).chr(91);
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(^;x)";
    $nyes=chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="( ;x)";
    $nyes=" ".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    $yes="(\n;x)";
    $nyes="\n".chr(165)."x";
    $ntxt=ereg_replace($yes,$nyes,$ntxt);
    return($ntxt);
}


?>
